History
=======

Unreleased
----------

* Add a command-line interface (:code:`skt`) with subcommands for cleaning
  text, obtaining syllables and varṇa decomposition.
* Add a basic unit test suite covering core utilities and the CLI.
* Fix ``marker_to_swara`` for extended mātrā characters.
* Update packaging metadata and Trove classifiers for a production-ready
  release.

0.2.3 (2022-09-14)
------------------

* Clarify documentation for ``join_varna`` and update general project
  documentation.

0.2.2 (2022-09-13)
------------------

* Add two missing nuktā consonants to the alphabet definitions.

0.2.1 (2022-09-07)
------------------

* Resolve a merge issue affecting the codebase.

0.2.0 (2022-09-07)
------------------

* Reformat code with Black and improve documentation.

0.1.1 (2022-07-05)
------------------

* Packaging and release metadata updates.

0.1.0 (2022-07-03)
------------------

* First release on PyPI.
